Creates and returns a Shiny application for exploring antimicrobial resistance data and machine learning model results.
launchAMRDashboard(results_root = NULL, amrdata_root = NULL)File path to the root directory containing amRml model
output results. If NULL (default), the application will attempt to
use example data bundled with the package, where available.
File path to the root directory containing amRdata
annotation parquets (e.g. cluster_feature_COG.parquet,
gene_names.parquet). If NULL (default), ~/amRdata/data is used
when present; otherwise annotation-based features are disabled.
A Shiny application object
if (interactive()) {
app <- launchAMRDashboard()
shiny::runApp(app)
}